@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "evil-matchit" "4.0.1"
+(define-package "evil-matchit" "20251212.1256"
   "Vim matchit ported to Evil."
   '((emacs "27.1"))
   :url "http://github.com/redguardtoo/evil-matchit"
-  :commit "84a6d34c1a1282c43c6ccef2ead3eaa41fd1535f"
-  :revdesc "84a6d34c1a12"
+  :commit "eb2b0c776c9d1cf3199c24473499ce4adfa44178"
+  :revdesc "eb2b0c776c9d"
   :keywords '("matchit" "vim" "evil")
   :authors '(("Chen Bin" . "chenbin.sh@gmail.com"))
   :maintainers '(("Chen Bin" . "chenbin.sh@gmail.com")))
